History
=======

1.3.1 (2013-10-24)
++++++++++++++++++

- Add `is_found` attribute for `HaulResult`
- Add `to_ordered_dict()` method for `HaulResult`
- `A demo site on Heroku <http://hauler.herokuapp.com/>`_


1.3.0 (2013-10-16)
++++++++++++++++++

- Use unicode for every string
- Fix running test.py from another directory
- Rename module `models` to `core`
- Remove in_ignorecase()


1.2.0 (2013-10-15)
++++++++++++++++++

- Improve error handling


1.1.0 (2013-10-04)
++++++++++++++++++

- Custom finder / extender pipeline support


1.0.0 (2013-10-03)
++++++++++++++++++

- Initial release
